﻿'
' DotNetNuke® - http://www.dotnetnuke.com
' Copyright (c) 2002-2008
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Imports System.Xml
Imports DotNetNuke.Common.Utilities

Namespace DotNetNuke.Modules.News
 ''' <summary>
 ''' Class for common methods
 ''' </summary>
 ''' <remarks>
 ''' </remarks>
 ''' <history>
 ''' 	[pdonker]	03/01/2008  Created
 ''' </history>
 Public Class Common

  ''' <summary>
  ''' Get the en/decryption key from the web.config
  ''' </summary>
  ''' <returns>Encryption key (as string)</returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Function GetEncryptionKey() As String
   Try
    Dim xmlConfig As XmlDocument = Config.Load
    Dim xmlMachineKey As XmlNode = xmlConfig.SelectSingleNode("configuration/system.web/machineKey")
    Return xmlMachineKey.Attributes("decryptionKey").InnerText
   Catch ex As Exception
    Return ""
   End Try
  End Function

  ''' <summary>
  ''' Save a block of text to a file
  ''' </summary>
  ''' <param name="FileName">Full path to file. File will be created or overwritten.</param>
  ''' <param name="Text">Text to write to the file.</param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Sub SaveTextToFile(ByVal FileName As String, ByVal Text As String)
   Dim sw As New IO.StreamWriter(FileName, False)
   sw.WriteLine(Text)
   sw.Flush()
   sw.Close()
   sw = Nothing
  End Sub

  ''' <summary>
  ''' Write feed as text to a file.
  ''' </summary>
  ''' <param name="feed">Rss XML Document to save.</param>
  ''' <param name="ModuleId">ModuleId</param>
  ''' <param name="CachePath">Absolute path to the caching directory.</param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Sub SaveResultFeed(ByVal feed As XmlDocument, ByVal ModuleId As Integer, ByVal CachePath As String)
   SaveTextToFile(CachePath & CacheFeedname(ModuleId), feed.OuterXml)
  End Sub

  ''' <summary>
  ''' Get the name for the cache file for this module ID
  ''' </summary>
  ''' <param name="ModuleId">Module ID</param>
  ''' <returns>Filename to be used to store the feed.</returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Function CacheFeedname(ByVal ModuleId As Integer) As String
   Return "Feed_" & ModuleId.ToString & ".resources"
  End Function

  ''' <summary>
  ''' Gets a string regardless of the input.
  ''' </summary>
  ''' <param name="Value">An object that we try to convert to string.</param>
  ''' <returns>String value of object</returns>
  ''' <remarks>This method will prevent conversion errors when dealing with NULLs.</remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Function GetAString(ByVal Value As Object) As String
   If Value Is Nothing Then
    Return ""
   Else
    If Value Is DBNull.Value Then
     Return ""
    Else
     Return CType(Value, String)
    End If
   End If
  End Function
 End Class
End Namespace
