'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2008
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Imports System.Xml.Xsl

Namespace DotNetNuke.Modules.News
 ''' <summary>
 ''' Settings class for module
 ''' </summary>
 ''' <remarks>
 ''' </remarks>
 ''' <history>
 ''' 	[pdonker]	03/01/2008  Created
 ''' </history>
 Public Class ModuleSettings

#Region " Private Members "
  Private _moduleId As Integer = -1
  Private _settings As Hashtable = Nothing
  Private _DefaultCacheTime As Integer = 30
  Private _XslUrl As String = ""
  Private _ItemsToShow As Integer = -1
  Private _ShowItemDetails As Boolean = True
  Private _ShowItemDate As Boolean = True
  Private _RetryTimes As Integer = 3
  Private _RetryTimeOut As Integer = 120
  Private _UseAjax As Boolean = True
#End Region

#Region " Constructor "
  ''' <summary>
  ''' Gets settings from ModuleSettings table.
  ''' </summary>
  ''' <param name="ModuleId"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Sub New(ByVal ModuleId As Integer)

   _moduleId = ModuleId
   _settings = (New DotNetNuke.Entities.Modules.ModuleController).GetModuleSettings(ModuleId)

   If Not _settings.Item("DefaultCacheTime") Is Nothing Then
    DefaultCacheTime = CType(_settings.Item("DefaultCacheTime"), Integer)
   End If

   If Not _settings.Item("XslUrl") Is Nothing Then
    XslUrl = CType(_settings.Item("XslUrl"), String)
   End If

   If Not _settings.Item("ItemsToShow") Is Nothing Then
    ItemsToShow = CType(_settings.Item("ItemsToShow"), Integer)
   End If

   If Not _settings.Item("ShowItemDetails") Is Nothing Then
    ShowItemDetails = CType(_settings.Item("ShowItemDetails"), Boolean)
   End If

   If Not _settings.Item("ShowItemDate") Is Nothing Then
    ShowItemDate = CType(_settings.Item("ShowItemDate"), Boolean)
   End If

   If Not _settings.Item("RetryTimes") Is Nothing Then
    RetryTimes = CType(_settings.Item("RetryTimes"), Integer)
   End If

   If Not _settings.Item("RetryTimeOut") Is Nothing Then
    RetryTimeOut = CType(_settings.Item("RetryTimeOut"), Integer)
   End If

   If Not _settings.Item("UseAjax") Is Nothing Then
    UseAjax = CType(_settings.Item("UseAjax"), Boolean)
   End If

  End Sub
#End Region

#Region " Public Methods "
  ''' <summary>
  ''' Save settings to ModuleSettings table
  ''' </summary>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Sub Save()
   Dim objModules As New DotNetNuke.Entities.Modules.ModuleController
   objModules.UpdateModuleSetting(_moduleId, "DefaultCacheTime", Me.DefaultCacheTime.ToString)
   objModules.UpdateModuleSetting(_moduleId, "XslUrl", Me.XslUrl.ToString)
   objModules.UpdateModuleSetting(_moduleId, "ItemsToShow", Me.ItemsToShow.ToString)
   objModules.UpdateModuleSetting(_moduleId, "ShowItemDetails", Me.ShowItemDetails.ToString)
   objModules.UpdateModuleSetting(_moduleId, "ShowItemDate", Me.ShowItemDate.ToString)
   objModules.UpdateModuleSetting(_moduleId, "RetryTimes", Me.RetryTimes.ToString)
   objModules.UpdateModuleSetting(_moduleId, "RetryTimeOut", Me.RetryTimeOut.ToString)
   objModules.UpdateModuleSetting(_moduleId, "UseAjax", Me.UseAjax.ToString)
   DotNetNuke.Common.Utilities.DataCache.RemoveCache(CacheKey(_moduleId))
  End Sub

  ''' <summary>
  ''' Get list of parameters for the XSL transformation
  ''' </summary>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Function GetParameterList() As XsltArgumentList
   Dim res As New XsltArgumentList
   res.AddParam("ItemsToShow", "", Me.ItemsToShow)
   res.AddParam("ShowItemDetails", "", Me.ShowItemDetails)
   res.AddParam("ShowItemDate", "", Me.ShowItemDate)
   res.AddParam("Locale", "", Threading.Thread.CurrentThread.CurrentUICulture.Name)
   Return res
  End Function
#End Region

#Region " Properties "
  ''' <summary>
  ''' Defautl Cache time. All feeds are assumed to have this cache time unless specified otherwise.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property DefaultCacheTime() As Integer
   Get
    Return _DefaultCacheTime
   End Get
   Set(ByVal Value As Integer)
    _DefaultCacheTime = Value
   End Set
  End Property

  ''' <summary>
  ''' Url of transformation
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property XslUrl() As String
   Get
    Return _XslUrl
   End Get
   Set(ByVal Value As String)
    _XslUrl = Value
   End Set
  End Property

  ''' <summary>
  ''' Number of items to show of the aggregated feed. This is passed as parameter to the transformation.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property ItemsToShow() As Integer
   Get
    Return _ItemsToShow
   End Get
   Set(ByVal Value As Integer)
    _ItemsToShow = Value
   End Set
  End Property

  ''' <summary>
  ''' Boolean whether or not to show the description of the item. This is passed as parameter to the transformation.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property ShowItemDetails() As Boolean
   Get
    Return _ShowItemDetails
   End Get
   Set(ByVal Value As Boolean)
    _ShowItemDetails = Value
   End Set
  End Property

  ''' <summary>
  ''' Boolean whether or not to show the pub date of the item. This is passed as parameter to the transformation.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property ShowItemDate() As Boolean
   Get
    Return _ShowItemDate
   End Get
   Set(ByVal Value As Boolean)
    _ShowItemDate = Value
   End Set
  End Property

  ''' <summary>
  ''' Number of times to retry getting the feed.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Property RetryTimes() As Integer
   Get
    Return _RetryTimes
   End Get
   Set(ByVal Value As Integer)
    _RetryTimes = Value
   End Set
  End Property

  ''' <summary>
  ''' Timeout observed for retries. After RetryTimes nr of retries this timeout will be observed before retrying again.
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks></remarks>
  Public Property RetryTimeOut() As Integer
   Get
    Return _RetryTimeOut
   End Get
   Set(ByVal Value As Integer)
    _RetryTimeOut = Value
   End Set
  End Property

  ''' <summary>
  ''' Use Ajax (if present)
  ''' </summary>
  ''' <value></value>
  ''' <returns></returns>
  ''' <remarks></remarks>
  Public Property UseAjax() As Boolean
   Get
    Return _UseAjax
   End Get
   Set(ByVal value As Boolean)
    _UseAjax = value
   End Set
  End Property
#End Region

#Region " Static Methods "
  ''' <summary>
  ''' Gets the module's settings and caches them
  ''' </summary>
  ''' <param name="ModuleId">Module ID</param>
  ''' <returns>These settings</returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Shared Function GetModuleSettings(ByVal ModuleId As Integer) As ModuleSettings
   Dim modSettings As ModuleSettings = Nothing
   Try
    modSettings = CType(DotNetNuke.Common.Utilities.DataCache.GetCache(CacheKey(ModuleId)), ModuleSettings)
   Catch
   End Try
   If modSettings Is Nothing Then
    modSettings = New ModuleSettings(ModuleId)
    Dim CacheMins As Integer
    CacheMins = 3 * Convert.ToInt32(DotNetNuke.Common.Globals.PerformanceSetting)
    If CacheMins > 0 Then
     DotNetNuke.Common.Utilities.DataCache.SetCache(CacheKey(ModuleId), modSettings, Nothing, Date.MaxValue, New TimeSpan(0, CacheMins, 0))
    End If
   End If
   Return modSettings
  End Function

  ''' <summary>
  ''' Key to use for caching these settings.
  ''' </summary>
  ''' <param name="ModuleId"></param>
  ''' <returns>Key as string</returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Shared Function CacheKey(ByVal ModuleId As Integer) As String
   Return "NewsSettingsModule" & ModuleId.ToString
  End Function
#End Region

 End Class
End Namespace