'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2008
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Imports System.Web.UI.WebControls

Imports DotNetNuke.Common
Imports DotNetNuke.Services.Exceptions
Imports DotNetNuke.Services.Localization.Localization
Imports DotNetNuke.Modules.News.Business

Namespace DotNetNuke.Modules.News
 ''' <summary>
 ''' Control to edit the definition of an aggregated feed.
 ''' </summary>
 ''' <remarks>
 ''' </remarks>
 ''' <history>
 ''' 	[pdonker]	03/01/2008  Created
 ''' </history>
 Partial Public Class EditRss
  Inherits Modulebase

#Region " Private Members "
  Private _opml As String = ""
  Private _feeds As DataTable = Nothing
  Private _inEditFeedId As Integer = 0
#End Region

#Region " Public Members "
  Public ReadOnly Property InEditFeedId() As Integer
   Get
    Return _inEditFeedId
   End Get
  End Property
#End Region

#Region " Controls "
#End Region

#Region " Event Handlers "
  ''' <summary>
  ''' Called upon Page Load
  ''' </summary>
  ''' <param name="sender"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
   Try

    If Not Page.IsPostBack Then
     _feeds = DotNetNuke.Common.ConvertDataReaderToDataTable(Data.DataProvider.Instance().GetFeedsByModule(ModuleId))
     _feeds.PrimaryKey = New DataColumn() {_feeds.Columns.Item("FeedId")}
     BindList()
    End If

   Catch exc As Exception    'Module failed to load
    ProcessModuleLoadException(Me, exc)
   End Try
  End Sub

  ''' <summary>
  ''' Called upon Page Prerender
  ''' </summary>
  ''' <param name="sender"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub Page_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.PreRender
   If InEditFeedId <> 0 Then
    If dlFeeds.EditItemIndex = -1 Then ' we had an add command and the DataList is not yet in edit
     For Each dli As DataListItem In dlFeeds.Items
      If CInt(dlFeeds.DataKeys(dli.ItemIndex)) = InEditFeedId Then
       dlFeeds.EditItemIndex = dli.ItemIndex
       BindList()
       Exit For
      End If
     Next
    End If
    Dim txtPW As TextBox = CType(dlFeeds.Items(dlFeeds.EditItemIndex).FindControl("txtPassword"), TextBox)
    If txtPW.Text <> "" Then
     txtPW.Text = GetString("PasswordEncoded", Me.LocalResourceFile)
     txtPW.Attributes.Add("onclick", "Javascript:this.value='';")
    End If
    cmdCancel.Enabled = False
    cmdUpdate.Enabled = False
    CType(dlFeeds.Controls(dlFeeds.Controls.Count - 1).FindControl("cmdAdd"), LinkButton).Enabled = False
   Else
    cmdCancel.Enabled = True
    cmdUpdate.Enabled = True
    CType(dlFeeds.Controls(dlFeeds.Controls.Count - 1).FindControl("cmdAdd"), LinkButton).Enabled = True
   End If
  End Sub

  ''' <summary>
  ''' Update all settings and go back to page.
  ''' </summary>
  ''' <param name="sender"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub cmdUpdate_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdUpdate.Click
   Try
    If Page.IsValid Then
     For Each drFeed As DataRow In _feeds.Select("", "", DataViewRowState.CurrentRows)
      Dim FeedId As Integer = CInt(drFeed.Item("FeedId"))
      Dim FeedUrl As String = Common.GetAString(drFeed.Item("FeedUrl"))
      If FeedId < 0 Then
       If Not String.IsNullOrEmpty(FeedUrl) Then
        Dim feed As New FeedInfo
        With feed
         .CacheTime = CInt(drFeed.Item("CacheTime"))
         .FeedUrl = FeedUrl
         .ModuleID = ModuleId
         .User = Common.GetAString(drFeed.Item("User"))
         .Password = Common.GetAString(drFeed.Item("Password"))
        End With
        FeedController.AddFeed(feed)
       End If
      Else
       If Not String.IsNullOrEmpty(FeedUrl) Then
        Dim feed As FeedInfo = FeedController.GetFeed(FeedId, ModuleId)
        With feed
         .CacheTime = CInt(drFeed.Item("CacheTime"))
         .FeedUrl = FeedUrl
         .User = Common.GetAString(drFeed.Item("User"))
         .Password = Common.GetAString(drFeed.Item("Password"))
        End With
        FeedController.UpdateFeed(feed)
       Else
        FeedController.DeleteFeed(FeedId)
       End If
      End If
     Next
     For Each drFeed As DataRow In _feeds.Select("", "", DataViewRowState.Deleted)
      Dim FeedId As Integer = CInt(drFeed.Item("FeedId", DataRowVersion.Original))
      If FeedId > 0 Then
       FeedController.DeleteFeed(FeedId)
      End If
     Next
     FeedController.ClearFeedsCache(ModuleId)
     If IO.File.Exists(Me.PortalSettings.HomeDirectoryMapPath & "\Cache\" & Common.CacheFeedname(ModuleId)) Then
      IO.File.Delete(Me.PortalSettings.HomeDirectoryMapPath & "\Cache\" & Common.CacheFeedname(ModuleId))
     End If
     ' Redirect back to the portal home page
     Response.Redirect(NavigateURL(), True)
    End If
   Catch exc As Exception    'Module failed to load
    ProcessModuleLoadException(Me, exc)
   End Try
  End Sub

  ''' <summary>
  ''' Cancel edits and go back to page.
  ''' </summary>
  ''' <param name="sender"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub cmdCancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdCancel.Click
   Try
    Response.Redirect(NavigateURL(), True)
   Catch exc As Exception    'Module failed to load
    ProcessModuleLoadException(Me, exc)
   End Try
  End Sub

  ''' <summary>
  ''' Cancel edit of feed in datalist
  ''' </summary>
  ''' <param name="source"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub dlFeeds_CancelCommand(ByVal source As Object, ByVal e As System.Web.UI.WebControls.DataListCommandEventArgs) Handles dlFeeds.CancelCommand
   If _inEditFeedId < 0 Then
    Dim dr As DataRow = _feeds.Rows.Find(_inEditFeedId)
    If dr IsNot Nothing Then
     If dr.Item("FeedUrl") Is DBNull.Value OrElse CStr(dr.Item("FeedUrl")).Trim = "" Then
      dr.Delete()
     End If
    End If
   End If
   dlFeeds.EditItemIndex = -1
   _inEditFeedId = 0
   BindList()
  End Sub

  ''' <summary>
  ''' Delete feed from list
  ''' </summary>
  ''' <param name="source"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub dlFeeds_DeleteCommand(ByVal source As Object, ByVal e As System.Web.UI.WebControls.DataListCommandEventArgs) Handles dlFeeds.DeleteCommand
   Dim FeedId As Integer = CInt(dlFeeds.DataKeys(e.Item.ItemIndex))
   Dim dr As DataRow = _feeds.Rows.Find(FeedId)
   If dr IsNot Nothing Then
    dr.Delete()
   End If
   BindList()
  End Sub

  ''' <summary>
  ''' Edit feed in list
  ''' </summary>
  ''' <param name="source"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub dlFeeds_EditCommand(ByVal source As Object, ByVal e As System.Web.UI.WebControls.DataListCommandEventArgs) Handles dlFeeds.EditCommand
   dlFeeds.EditItemIndex = e.Item.ItemIndex
   _inEditFeedId = CInt(dlFeeds.DataKeys(e.Item.ItemIndex))
   BindList()
  End Sub

  ''' <summary>
  ''' Other commands in list. Used to add a new feed.
  ''' </summary>
  ''' <param name="source"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub dlFeeds_ItemCommand(ByVal source As Object, ByVal e As System.Web.UI.WebControls.DataListCommandEventArgs) Handles dlFeeds.ItemCommand

   Select Case e.CommandName.ToLower
    Case "add"
     _inEditFeedId = AddNewRow()
     BindList()
    Case Else
   End Select

  End Sub

  ''' <summary>
  ''' Update feed in definition
  ''' </summary>
  ''' <param name="source"></param>
  ''' <param name="e"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub dlFeeds_UpdateCommand(ByVal source As Object, ByVal e As System.Web.UI.WebControls.DataListCommandEventArgs) Handles dlFeeds.UpdateCommand
   Dim dr As DataRow = _feeds.Rows.Find(_inEditFeedId)
   If dr IsNot Nothing Then
    dr.Item("FeedUrl") = CType(e.Item.FindControl("txtFeedUrl"), TextBox).Text
    dr.Item("CacheTime") = CType(e.Item.FindControl("txtCacheTime"), TextBox).Text
    dr.Item("User") = CType(e.Item.FindControl("txtUser"), TextBox).Text
    Dim Password As String = CType(e.Item.FindControl("txtPassword"), TextBox).Text
    If Not String.IsNullOrEmpty(Password) Then
     Dim encKey As String = Common.GetEncryptionKey
     If Not String.IsNullOrEmpty(encKey) Then
      Dim ps As New DotNetNuke.Security.PortalSecurity
      Password = ps.Encrypt(encKey, Password)
     End If
     dr.Item("Password") = Password
    Else
     dr.Item("Password") = ""
    End If
   End If
   dlFeeds.EditItemIndex = -1
   _inEditFeedId = 0
   BindList()
  End Sub
#End Region

#Region " Private Methods "
  ''' <summary>
  ''' Make the datalist with feeds.
  ''' </summary>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Sub BindList()
   dlFeeds.DataSource = New DataView(_feeds, "", "FeedUrl", DataViewRowState.CurrentRows)
   dlFeeds.DataBind()
  End Sub

  ''' <summary>
  ''' Add new row to feeds table.
  ''' </summary>
  ''' <returns></returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Private Function AddNewRow() As Integer
   Dim i As Integer = -1
   For Each drFeed As DataRow In _feeds.Rows
    Dim id As Integer = -1
    Select Case drFeed.RowState
     Case DataRowState.Deleted
      id = CInt(drFeed.Item("FeedId", DataRowVersion.Original))
     Case Else
      id = CInt(drFeed.Item("FeedId", DataRowVersion.Default))
    End Select
    If id <= i Then
     i = id - 1
    End If
   Next
   Dim dr As DataRow = _feeds.NewRow
   dr.Item("FeedId") = i
   dr.Item("CacheTime") = -1
   _feeds.Rows.Add(dr)
   Return i
  End Function
#End Region

#Region " ViewState Handling "
  ''' <summary>
  ''' Load variables from ViewState
  ''' </summary>
  ''' <param name="savedState"></param>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Protected Overrides Sub LoadViewState(ByVal savedState As Object)

   If Not (savedState Is Nothing) Then
    Dim myState As Object() = CType(savedState, Object())
    If Not (myState(0) Is Nothing) Then
     MyBase.LoadViewState(myState(0))
    End If
    If Not (myState(1) Is Nothing) Then
     _feeds = CType(myState(1), DataTable)
    End If
    If Not (myState(2) Is Nothing) Then
     _inEditFeedId = CInt(myState(2))
    End If
   End If

   Me.EnsureChildControls()

  End Sub

  ''' <summary>
  ''' Save variables to ViewState
  ''' </summary>
  ''' <returns>ViewState object</returns>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Protected Overrides Function SaveViewState() As Object

   Dim allStates(2) As Object
   allStates(0) = MyBase.SaveViewState()
   allStates(1) = _feeds
   allStates(2) = _inEditFeedId
   Return allStates

  End Function
#End Region

 End Class
End Namespace