'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.IO
Imports System.Text
Imports System.Xml
Imports System.Xml.Serialization
Imports DotNetNuke.Modules.News.RssToolkit
Imports DotNetNuke.Modules.News.RssToolkit.Rss

Namespace DotNetNuke.Modules.News.RssToolkit.Opml
	''' <summary>
	''' OpmlDocument
	''' </summary>
	<Serializable()> _
	<XmlRoot("opml")> _
	Public Class OpmlDocument
		Private m_version As String
		Private m_head As OpmlHead
		Private m_body As OpmlBody

		''' <summary>
		''' Gets or sets the version.
		''' </summary>
		''' <value>The version.</value>
		<XmlAttribute("version")> _
		Public Property Version() As String
			Get
				Return m_version
			End Get

			Set
				m_version = value
			End Set
		End Property

		''' <summary>
		''' Gets or sets the head.
		''' </summary>
		''' <value>The head.</value>
		<XmlElement("head")> _
		Public Property Head() As OpmlHead
			Get
				Return m_head
			End Get

			Set
				m_head = value
			End Set
		End Property

		''' <summary>
		''' Gets or sets the body.
		''' </summary>
		''' <value>The body.</value>
		<XmlElement("body")> _
		Public Property Body() As OpmlBody
			Get
				Return m_body
			End Get

			Set
				m_body = value
			End Set
		End Property

		''' <summary>
		''' Loads from URL.
		''' </summary>
		''' <param name="url">The URL.</param>
		''' <returns>OpmlDocument</returns>
  ''' <history>
  ''' 	[pdonker]	01/03/2008  Caching directory no longer retrieved from web.config but passed as a parameter
  ''' </history>
  Public Shared Function Load(ByVal url As System.Uri, ByVal tempDir As String) As OpmlDocument
   If url Is Nothing Then
    Throw New ArgumentNullException("url")
   End If

   Dim opmlXml As String = String.Empty
   Using opmlStream As Stream = DownloadManager.GetFeed(url.ToString(), tempDir)
    Using reader As New XmlTextReader(opmlStream)
     While reader.Read()
      If reader.NodeType = XmlNodeType.Element AndAlso reader.LocalName.Equals("opml", StringComparison.OrdinalIgnoreCase) Then
       opmlXml = reader.ReadOuterXml()
       Exit While
      End If
     End While
    End Using
   End Using

   Return Load(opmlXml)
  End Function

		''' <summary>
		''' Loads from XML.
		''' </summary>
		''' <param name="xml">The XML.</param>
		''' <returns>OpmlDocument</returns>
		Public Shared Function Load(ByVal xml As String) As OpmlDocument
			If [String].IsNullOrEmpty(xml) Then
    Throw New ArgumentException(String.Format(DotNetNuke.Modules.News.RssToolkit.Rss.Resources.RssToolkit.Culture, DotNetNuke.Modules.News.RssToolkit.Rss.Resources.RssToolkit.ArgmentException, "xml"))
			End If

			Dim doc As New OpmlDocument()
			Using stringReader As New StringReader(xml)
				Dim x As New XmlSerializer(GetType(OpmlDocument))
				Using xmlReader As New XmlTextReader(stringReader)
					doc = DirectCast(x.Deserialize(xmlReader), OpmlDocument)
				End Using
			End Using

			Return doc
		End Function
	End Class
End Namespace
