'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
'
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.CodeDom
Imports System.CodeDom.Compiler
Imports System.Collections.Generic
Imports System.IO
Imports System.Web
Imports System.Web.Compilation
Imports System.Web.Hosting
Imports System.Xml

Namespace DotNetNuke.Modules.News.RssToolkit.Rss.CodeGeneration
	''' <summary>
	''' build provided for .rss file - channel definition in app_code
	''' generates strongly-typed channel type
	''' </summary>
	<BuildProviderAppliesTo(BuildProviderAppliesTo.Code)> _
	Public NotInheritable Class RssBuildProvider
		Inherits BuildProvider
		''' <summary>
		''' Generates source code for the virtual path of the build provider, and adds the source code to a specified assembly builder.
		''' </summary>
		''' <param name="assemblyBuilder">The assembly builder that references the source code generated by the build provider.</param>
		Public Overloads Overrides Sub GenerateCode(ByVal assemblyBuilder As AssemblyBuilder)
			If assemblyBuilder Is Nothing Then
				Throw New ArgumentNullException("assemblyBuilder")
			End If

			' get name and namespace from the filename
			Dim ns As String = String.Empty
			Dim name As String = VirtualPathUtility.GetFileName(VirtualPath)
			Dim i As Integer = name.LastIndexOf("."C)

			If i > 0 Then
				name = name.Substring(0, i)
				' discard extension
				i = name.LastIndexOf("."C)
				' and split into namespace and class
				If i > 0 Then
					name = name.Substring(i + 1)
					ns = name.Substring(0, i)
				End If
			End If

			' load as XML
			Dim doc As New XmlDocument()
			Using s As Stream = OpenStream(VirtualPath)
				doc.Load(s)
			End Using

			' compile the channel
			Dim ccu As New CodeCompileUnit()
			RssCodeGenerator.GenerateCodeDomTree(doc.OuterXml, String.Empty, ns, name, ccu, True)
			assemblyBuilder.AddCodeCompileUnit(Me, ccu)
		End Sub
	End Class
End Namespace
