'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.Xml.Serialization

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	''' RssChannel
	''' </summary>
 ''' <history>
 ''' 	[pdonker]	01/03/2008  Changed position of Items to avoid errors in Rss20 generation
 ''' </history>
 <Serializable()> _
 Public Class RssChannel
  Private _categories As List(Of RssCategory)
  Private _copyright As String
  Private _description As String
  Private _docs As String
  Private _cloud As RssCloud
  Private _generator As String
  Private _image As RssImage
  Private _items As List(Of RssItem)
  Private _lastBuildDate As String
  Private _link As String
  Private _managingEditor As String
  Private _pubDate As String
  Private _rating As String
  Private _timeToLive As String
  Private _title As String
  Private _skipDays As RssSkipDays
  Private _skipHours As RssSkipHours
  Private _webMaster As String
  Private _language As String
  Private _textInput As RssTextInput

  ''' <summary>
  ''' Gets or sets the categories.
  ''' </summary>
  ''' <value>The categories.</value>
  <System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists"), XmlElement("category")> _
  Public Property Categories() As List(Of RssCategory)
   Get
    Return _categories
   End Get

   Set(ByVal value As List(Of RssCategory))
    _categories = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the cloud.
  ''' </summary>
  ''' <value>The cloud.</value>
  <XmlElement("cloud")> _
  Public Property Cloud() As RssCloud
   Get
    Return _cloud
   End Get

   Set(ByVal value As RssCloud)
    _cloud = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the copyright.
  ''' </summary>
  ''' <value>The copyright.</value>
  <XmlElement("copyright")> _
  Public Property Copyright() As String
   Get
    Return _copyright
   End Get

   Set(ByVal value As String)
    _copyright = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the description.
  ''' </summary>
  ''' <value>The description.</value>
  <XmlElement("description")> _
  Public Property Description() As String
   Get
    Return _description
   End Get

   Set(ByVal value As String)
    _description = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the docs.
  ''' </summary>
  ''' <value>The docs.</value>
  <XmlElement("docs")> _
  Public Property Docs() As String
   Get
    Return _docs
   End Get

   Set(ByVal value As String)
    _docs = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the generator.
  ''' </summary>
  ''' <value>The generator.</value>
  <XmlElement("generator")> _
  Public Property Generator() As String
   Get
    Return _generator
   End Get

   Set(ByVal value As String)
    _generator = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the last build date.
  ''' </summary>
  ''' <value>The last build date.</value>
  <XmlElement("lastBuildDate")> _
  Public Property LastBuildDate() As String
   Get
    Return _lastBuildDate
   End Get

   Set(ByVal value As String)
    _lastBuildDate = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the link.
  ''' </summary>
  ''' <value>The link.</value>
  <XmlElement("link")> _
  Public Property Link() As String
   Get
    Return _link
   End Get

   Set(ByVal value As String)
    _link = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the managing editor.
  ''' </summary>
  ''' <value>The managing editor.</value>
  <XmlElement("managingEditor")> _
  Public Property ManagingEditor() As String
   Get
    Return _managingEditor
   End Get

   Set(ByVal value As String)
    _managingEditor = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the time to live.
  ''' </summary>
  ''' <value>The time to live.</value>
  <XmlElement("ttl")> _
  Public Property TimeToLive() As String
   Get
    Return _timeToLive
   End Get

   Set(ByVal value As String)
    _timeToLive = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the title.
  ''' </summary>
  ''' <value>The title.</value>
  <XmlElement("title")> _
  Public Property Title() As String
   Get
    Return _title
   End Get

   Set(ByVal value As String)
    _title = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the pub date.
  ''' </summary>
  ''' <value>The pub date.</value>
  <XmlElement("pubDate")> _
  Public Property PubDate() As String
   Get
    Return _pubDate
   End Get

   Set(ByVal value As String)
    _pubDate = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the rating.
  ''' </summary>
  ''' <value>The rating.</value>
  <XmlElement("rating")> _
  Public Property Rating() As String
   Get
    Return _rating
   End Get

   Set(ByVal value As String)
    _rating = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the skip days.
  ''' </summary>
  ''' <value>The skip days.</value>
  <XmlElement("skipDays")> _
  Public Property SkipDays() As RssSkipDays
   Get
    Return _skipDays
   End Get

   Set(ByVal value As RssSkipDays)
    _skipDays = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the skip hours.
  ''' </summary>
  ''' <value>The skip hours.</value>
  <XmlElement("skipHours")> _
  Public Property SkipHours() As RssSkipHours
   Get
    Return _skipHours
   End Get

   Set(ByVal value As RssSkipHours)
    _skipHours = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the web master.
  ''' </summary>
  ''' <value>The web master.</value>
  <XmlElement("webMaster")> _
  Public Property WebMaster() As String
   Get
    Return _webMaster
   End Get

   Set(ByVal value As String)
    _webMaster = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the image.
  ''' </summary>
  ''' <value>The image.</value>
  <XmlElement("image")> _
  Public Property Image() As RssImage
   Get
    Return _image
   End Get

   Set(ByVal value As RssImage)
    _image = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the language.
  ''' </summary>
  ''' <value>The language.</value>
  <XmlElement("language")> _
  Public Property Language() As String
   Get
    Return _language
   End Get

   Set(ByVal value As String)
    _language = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the text input.
  ''' </summary>
  ''' <value>The text input.</value>
  <XmlElement("textInput")> _
  Public Property TextInput() As RssTextInput
   Get
    Return _textInput
   End Get

   Set(ByVal value As RssTextInput)
    _textInput = value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the items.
  ''' </summary>
  ''' <value>The items.</value>
  <System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists"), XmlElement("item")> _
  Public Property Items() As List(Of RssItem)
   Get
    Return _items
   End Get

   Set(ByVal value As List(Of RssItem))
    _items = value
   End Set
  End Property
 End Class
End Namespace
