'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Data
Imports System.Collections
Imports System.Configuration
Imports System.IO
Imports System.Text
Imports System.Xml
Imports System.Xml.Serialization

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	''' RssDocument
	''' </summary>
 ''' <history>
 ''' 	[pdonker]	01/03/2008  Caching directory no longer retrieved from web.config but passed as a parameter
 ''' </history>
 <Serializable()> _
 <XmlRoot("rss")> _
 Public Class RssDocument
  Inherits RssDocumentBase
  Private _version As String
  Private _channel As RssChannel

  ''' <summary>
  ''' Initializes a new instance of the <see cref="RssDocument"/> class.
  ''' </summary>
  Public Sub New()
  End Sub

#Region "Properties"
  ''' <summary>
  ''' Gets or sets the version.
  ''' </summary>
  ''' <value>The version.</value>
  <XmlAttribute("version")> _
  Public Shadows Property Version() As String
   Get
    Return _version
   End Get

   Set(ByVal value As String)
    _version = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the channel.
  ''' </summary>
  ''' <value>The channel.</value>
  <XmlElement("channel")> _
  Public Shadows Property Channel() As RssChannel
   Get
    Return _channel
   End Get

   Set(ByVal value As RssChannel)
    _channel = Value
   End Set
  End Property
#End Region

  ''' <summary>
  ''' Loads from XML.
  ''' </summary>
  ''' <param name="xml">The XML.</param>
  ''' <returns>RssDocument</returns>
  Public Overloads Shared Function Load(ByVal xml As String, ByVal tempDir As String, ByRef originalType As DocumentType) As RssDocument
   Return RssDocumentBase.Load(Of RssDocument)(xml, tempDir, originalType)
  End Function

  ''' <summary>
  ''' Loads the specified URL.
  ''' </summary>
  ''' <param name="url">The URL.</param>
  ''' <returns>RssDocument</returns>
  Public Overloads Shared Function Load(ByVal url As System.Uri, ByVal tempDir As String, ByRef originalType As DocumentType) As RssDocument
   Return RssDocumentBase.Load(Of RssDocument)(url, tempDir, originalType)
  End Function

  ''' <summary>
  ''' Loads the specified reader.
  ''' </summary>
  ''' <param name="reader">The reader.</param>
  ''' <returns>RssDocument</returns>
  Public Overloads Shared Function Load(ByVal reader As XmlReader, ByVal tempDir As String, ByRef originalType As DocumentType) As RssDocument
   Return RssDocumentBase.Load(Of RssDocument)(reader, tempDir, originalType)
  End Function

  ''' <summary>
  ''' Coverts to DataSet
  ''' </summary>
  ''' <returns>DataSet</returns>
  Public Function ToDataSet() As DataSet
   Return RssXmlHelper.ToDataSet(ToXml(DocumentType.Rss20))
  End Function

  ''' <summary>
  ''' Select method for programmatic databinding
  ''' </summary>
  ''' <returns>IEnumerable</returns>
  Public Function SelectItems() As IEnumerable
   Return SelectItems(-1)
  End Function

  ''' <summary>
  ''' Selects the items.
  ''' </summary>
  ''' <param name="maxItems">The max items.</param>
  ''' <returns>IEnumerable</returns>
  Public Function SelectItems(ByVal maxItems As Integer) As IEnumerable
   Return SelectItems(maxItems, False)
  End Function

  ''' <summary>
  ''' Selects the items.
  ''' </summary>
  ''' <param name="maxItems">The max items.</param>
  ''' <param name="reverseOrder">if set to <c>true</c> [reverse order].</param>
  ''' <returns>IEnumerable</returns>
  Public Function SelectItems(ByVal maxItems As Integer, ByVal reverseOrder As Boolean) As IEnumerable
   Dim dataset As DataSet = Me.ToDataSet()
   Dim view As DataView = dataset.Tables("item").DefaultView

   If reverseOrder Then
    If view.Table.Columns.Contains("pubDateParsed") Then
     view.Sort = "pubDateParsed asc"
    End If
   End If

   If maxItems > 0 Then
    Dim clonedTable As DataTable = view.Table.Clone()
    For counter As Integer = 0 To maxItems - 1
     If counter >= view.Count Then
      Exit For
     End If

     clonedTable.ImportRow(view(counter).Row)
    Next

    Return New DataView(clonedTable, view.RowFilter, view.Sort, view.RowStateFilter)
   Else
    Return view
   End If
  End Function

  ''' <summary>
  ''' Returns Xml in the type specified by outputType
  ''' </summary>
  ''' <param name="outputType">Type of the output.</param>
  ''' <returns></returns>
  Public Overloads Overrides Function ToXml(ByVal outputType As DocumentType) As String
   Return RssDocumentBase.ToXml(Of RssDocument)(outputType, Me)
  End Function
 End Class
End Namespace
