'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.Web
Imports System.Web.Security
Imports System.Xml
Imports DotNetNuke.Modules.News.RssToolkit.Rss

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	'''  base class for RssHttpHandler - Generic handler and strongly typed ones are derived from it
	''' </summary>
	''' <typeparam name="RssRssType">RssDocumentBase</typeparam>
	Public MustInherit Class RssHttpHandlerBase(Of RssRssType As {RssDocumentBase, New})
		Implements IHttpHandler
		Private _rss As RssRssType
		Private _context As HttpContext

		''' <summary>
		''' Gets a value indicating whether another request can use the <see cref="T:System.Web.IHttpHandler"></see> instance.
		''' </summary>
		''' <value></value>
		''' <returns>true if the <see cref="T:System.Web.IHttpHandler"></see> instance is reusable; otherwise, false.</returns>
		Private ReadOnly Property IsReusable() As Boolean Implements IHttpHandler.IsReusable
			Get
				Return False
			End Get
		End Property

		''' <summary>
		''' Gets the RSS.
		''' </summary>
		''' <value>The RSS.</value>
		Protected ReadOnly Property Rss() As RssRssType
			Get
				Return _rss
			End Get
		End Property

		''' <summary>
		''' Gets the context.
		''' </summary>
		''' <value>The context.</value>
		Protected ReadOnly Property Context() As HttpContext
			Get
				Return _context
			End Get
		End Property

		''' <summary>
		''' Enables processing of HTTP Web requests by a custom HttpHandler that implements the <see cref="T:System.Web.IHttpHandler"></see> interface.
		''' </summary>
		''' <param name="context">An <see cref="T:System.Web.HttpContext"></see> object that provides references to the intrinsic server objects (for example, Request, Response, Session, and Server) used to service HTTP requests.</param>
  Public Sub ProcessRequest(ByVal context As HttpContext) Implements IHttpHandler.ProcessRequest
   If context Is Nothing Then
    Throw New ArgumentNullException("context")
   End If

   If context.Response Is Nothing Then
    Throw New ArgumentNullException("context.Response")
   End If

   _context = context

   ' create the Rss
   _rss = New RssRssType()

   ' parse the rss name and the user name from the query string
   Dim userName As String = Nothing
   Dim rssName As String = Nothing
   Dim documentType As DocumentType
   RssHttpHandlerHelper.ParseChannelQueryString(context.Request, rssName, userName, documentType)

   ' populate items (call the derived class)
   PopulateRss(rssName, userName)

   ' save XML into response
   Dim doc As New XmlDocument()
   Dim inputXml As String = _rss.ToXml(documentType)
   If documentType = documentType.Opml Then
    inputXml = inputXml.Replace("#FillValue#", context.Request.Url.ToString())
   End If

   doc.LoadXml(inputXml)
   context.Response.ContentType = "text/xml"
   doc.Save(context.Response.OutputStream)
  End Sub

		''' <summary>
		''' Populates the RSS.the only method derived classes are supposed to override
		''' </summary>
		''' <param name="rssName">Name of the RSS.</param>
		''' <param name="userName">Name of the user.</param>
		Protected Overridable Sub PopulateRss(ByVal rssName As String, ByVal userName As String)
		End Sub
	End Class
End Namespace
