'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
'
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.Web
Imports System.Web.Security

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	'''  helper class (for RssHtppHandler) to pack and unpack user name and channel to from/to query string
	''' </summary>
	Public NotInheritable Class RssHttpHandlerHelper
		Private Sub New()
		End Sub

		''' <summary>
		''' // helper to generate link [to the .ashx] containing channel name and (encoded) userName
		''' </summary>
		''' <param name="handlerPath">The handler path.</param>
		''' <param name="channelName">Name of the channel.</param>
		''' <param name="userName">Name of the user.</param>
		''' <returns>string</returns>
		Public Shared Function GenerateChannelLink(ByVal handlerPath As String, ByVal channelName As String, ByVal userName As String) As String
			Dim stringBuilder As New StringBuilder()
			stringBuilder.Append(handlerPath)

			If String.IsNullOrEmpty(userName) Then
				If Not String.IsNullOrEmpty(channelName) Then
					stringBuilder.Append("?c=" + HttpUtility.UrlEncodeUnicode(channelName))
				End If
			Else
				If channelName Is Nothing Then
					channelName = String.Empty
				End If

				userName = "." + userName
				' not to confuse the encrypted string with real auth ticket for real user
				Dim ticketDate As DateTime = DateTime.Now.AddDays(-100)
				' already expired
    Dim t As New FormsAuthenticationTicket(2, userName, ticketDate, ticketDate.AddDays(2), False, channelName, "/")

				stringBuilder.Append("?t=" + FormsAuthentication.Encrypt(t))
			End If

			Return stringBuilder.ToString()
		End Function

		Friend Shared Sub ParseChannelQueryString(ByVal request As HttpRequest, ByRef channelName As String, ByRef userName As String, ByRef outputType As DocumentType)
			Dim outputTypeQs As String = request.QueryString("outputtype")
			If Not String.IsNullOrEmpty(outputTypeQs) Then
				Try
					outputType = DirectCast([Enum].Parse(GetType(DocumentType), outputTypeQs, True), DocumentType)
				Catch generatedExceptionName As ArgumentException
     outputType = DocumentType.Rss20
				End Try
			Else
    outputType = DocumentType.Rss20
			End If

			Dim ticket As String = request.QueryString("t")
			If String.IsNullOrEmpty(ticket) Then
				userName = String.Empty
    '  optional unencrypted channel name
    channelName = request.QueryString("c")
   Else
    '  encrypted user name and channel name
    Dim t As FormsAuthenticationTicket = FormsAuthentication.Decrypt(ticket)
    userName = t.Name.Substring(1)
    '  remove extra prepended '.'
    channelName = t.UserData
			End If
		End Sub
	End Class
End Namespace
