'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
'
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.Text
Imports System.Xml.Serialization

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	''' RssItem
	''' </summary>
 ''' <history>
 ''' 	[pdonker]	01/03/2008  Added pubDateParsed
 ''' </history>
 <Serializable()> _
 Public Class RssItem
  Private _author As String
  Private _categories As List(Of RssCategory)
  Private _comments As String
  Private _description As String
  Private _enclosure As RssEnclosure
  Private _guid As RssGuid
  Private _link As String
  Private _pubDate As String
  Private _title As String
  Private _source As RssSource

  ''' <summary>
  ''' Gets or sets the author.
  ''' </summary>
  ''' <value>The author.</value>
  <XmlElement("author")> _
  Public Property Author() As String
   Get
    Return _author
   End Get

   Set(ByVal value As String)
    _author = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the categories.
  ''' </summary>
  ''' <value>The categories.</value>
  <System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1002:DoNotExposeGenericLists"), XmlElement("category")> _
  Public Property Categories() As List(Of RssCategory)
   Get
    Return _categories
   End Get

   Set(ByVal value As List(Of RssCategory))
    _categories = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the comments.
  ''' </summary>
  ''' <value>The comments.</value>
  <XmlElement("comments")> _
  Public Property Comments() As String
   Get
    Return _comments
   End Get

   Set(ByVal value As String)
    _comments = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the description.
  ''' </summary>
  ''' <value>The description.</value>
  <XmlElement("description")> _
  Public Property Description() As String
   Get
    Return _description
   End Get

   Set(ByVal value As String)
    _description = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the enclosure.
  ''' </summary>
  ''' <value>The enclosure.</value>
  <XmlElement("enclosure")> _
  Public Property Enclosure() As RssEnclosure
   Get
    Return _enclosure
   End Get

   Set(ByVal value As RssEnclosure)
    _enclosure = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the GUID.
  ''' </summary>
  ''' <value>The GUID.</value>
  <XmlElement("guid")> _
  Public Property Guid() As RssGuid
   Get
    Return _guid
   End Get

   Set(ByVal value As RssGuid)
    _guid = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the link.
  ''' </summary>
  ''' <value>The link.</value>
  <XmlElement("link")> _
  Public Property Link() As String
   Get
    Return _link
   End Get

   Set(ByVal value As String)
    _link = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the pub date.
  ''' </summary>
  ''' <value>The pub date.</value>
  <XmlElement("pubDate")> _
  Public Property PubDate() As String
   Get
    Return _pubDate
   End Get

   Set(ByVal value As String)
    _pubDate = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets the parsed pub date.
  ''' </summary>
  ''' <value>The parsed pub date.</value>
  <XmlElement("pubDateParsed", namespace:="http://www.dotnetnuke.com/modules/news")> _
  Public Property PubDateParsed() As Date
   Get
    Return RssXmlHelper.Parse(_pubDate)
   End Get

   Set(ByVal value As Date)
    _pubDate = RssXmlHelper.ToRfc822(value)
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the title.
  ''' </summary>
  ''' <value>The title.</value>
  <XmlElement("title")> _
  Public Property Title() As String
   Get
    Return _title
   End Get

   Set(ByVal value As String)
    _title = Value
   End Set
  End Property

  ''' <summary>
  ''' Gets or sets the source.
  ''' </summary>
  ''' <value>The source.</value>
  <XmlElement("source")> _
  Public Property Source() As RssSource
   Get
    Return _source
   End Get

   Set(ByVal value As RssSource)
    _source = Value
   End Set
  End Property
 End Class
End Namespace
