'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Xml
Imports System.Xml.Schema
Imports System.IO

Namespace DotNetNuke.Modules.News.RssToolkit.Rss
	''' <summary>
	''' Validates the Xml Schema
	''' </summary>
	Public Class RssXmlSchemaValidator
		Private m_isValidXml As Boolean = True
		Private m_validationError As String = String.Empty

		''' <summary>
		''' Initializes a new instance of the <see cref="RssXmlSchemaValidator"/> class.
		''' </summary>
		Public Sub New()
		End Sub

		''' <summary>
		''' Gets the validation error.
		''' </summary>
		''' <value>The validation error.</value>
		Public ReadOnly Property ValidationError() As String
			Get
				Return Me.m_validationError
			End Get
		End Property

		''' <summary>
		''' Gets a value indicating whether this instance is valid XML.
		''' </summary>
		''' <value>
		''' 	<c>true</c> if this instance is valid XML; otherwise, <c>false</c>.
		''' </value>
		Public ReadOnly Property IsValidXml() As Boolean
			Get
				Return Me.m_isValidXml
			End Get
		End Property

		''' <summary>
		''' Valids the Xml doc.
		''' </summary>
		''' <param name="xml">The XML.</param>
		''' <param name="xsd">The XSD.</param>
		<System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes")> _
		Public Sub ValidXmlDoc(ByVal xml As String, ByVal xsd As XmlReader)
			If String.IsNullOrEmpty(xml) Then
				Throw New ArgumentException(String.Format(Resources.RssToolkit.Culture, Resources.RssToolkit.ArgmentException, "xml"))
			End If

			If xsd Is Nothing Then
				Throw New ArgumentNullException("xsd")
			End If

			Try
				Dim sc As New XmlSchemaSet()
				sc.Add(Nothing, xsd)
				sc.Compile()

				Dim settings As New XmlReaderSettings()
				settings.ValidationType = ValidationType.Schema
				settings.Schemas = sc
				AddHandler settings.ValidationEventHandler, AddressOf ValidationCallBack
				Dim reader As XmlReader
				Using stringReader As New StringReader(xml)
					reader = XmlReader.Create(stringReader, settings)
					While reader.Read()
						

					End While
				End Using
			Catch ex As Exception
				Me.m_validationError = ex.Message
				m_isValidXml = False
			End Try
		End Sub

		Private Sub ValidationCallBack(ByVal sender As Object, ByVal args As ValidationEventArgs)
			' The xml does not match the schema.
			m_isValidXml = False
			Me.m_validationError = args.Message
		End Sub
	End Class
End Namespace
