'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
'
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Text
Imports System.Windows.Forms
Imports DotNetNuke.Modules.News.RssToolkit.Rss
Imports DotNetNuke.Modules.News.RssToolkit.Web.WebControls

Namespace DotNetNuke.Modules.News.RssToolkit.Web.Design
	''' <summary>
	''' WinForm dialog to configure RSS data source 
	''' </summary>
	Friend Partial Class RssDataSourceConfigForm
		Inherits Form
		Private Shared _history As New List(Of String)()
		Private _dataSource As RssDataSource

		''' <summary>
		''' Initializes a new instance of the <see cref="RssDataSourceConfigForm"/> class.
		''' </summary>
		''' <param name="dataSource">The data source.</param>
		Public Sub New(ByVal dataSource As RssDataSource)
			_dataSource = dataSource
			InitializeComponent()

			SyncLock _history
				AddToHistory(dataSource.Url)

				For Each url As String In _history
					urlComboBox.Items.Add(url)
				Next
			End SyncLock

			urlComboBox.Text = dataSource.Url
		End Sub

		Private Shared Sub AddToHistory(ByVal url As String)
			If String.IsNullOrEmpty(url) Then
				Return
			End If

			For Each s As String In _history
				If url = s Then
					Return
				End If
			Next

			_history.Insert(0, url)
		End Sub

		<System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Performance", "CA1804:RemoveUnusedLocals", MessageId := "rss"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1031:DoNotCatchGeneralExceptionTypes"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2201:DoNotRaiseReservedExceptionTypes"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1303:DoNotPassLiteralsAsLocalizedParameters", MessageId := "System.Windows.Forms.MessageBox.Show(System.Windows.Forms.IWin32Window,System.String,System.String,System.Windows.Forms.MessageBoxButtons,System.Windows.Forms.MessageBoxIcon)"), System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Globalization", "CA1300:SpecifyMessageBoxOptions")> _
		Private Sub button1_Click(ByVal sender As Object, ByVal e As EventArgs)
			Dim url As String = urlComboBox.Text

			If url <> _dataSource.Url Then
				Try
					Dim rss As RssDocument = RssDocument.Load(New System.Uri(url), Nothing)
					SyncLock _history
						AddToHistory(url)
					End SyncLock
				Catch
					MessageBox.Show(Me, "Failed to load RSS feed for the specified URL", "RssDataSource Error", MessageBoxButtons.OK, MessageBoxIcon.[Error])
					Return
				End Try
			End If

			_dataSource.Url = url
			DialogResult = DialogResult.OK
		End Sub
	End Class
End Namespace
