'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
'
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Text
Imports System.Web
Imports System.Web.UI
Imports System.Web.UI.Design
Imports System.Web.UI.WebControls
Imports System.Windows.Forms
Imports System.Windows.Forms.Design
Imports DotNetNuke.Modules.News.RssToolkit.Rss
Imports DotNetNuke.Modules.News.RssToolkit.Web.WebControls

Namespace DotNetNuke.Modules.News.RssToolkit.Web.Design
	''' <summary>
	''' Provides design-time support in a design host for the System.Web.UI.DataSourceControl class.
	''' </summary>
	Public Class RssDataSourceDesigner
		Inherits DataSourceDesigner
		Private _dataSource As RssDataSource
		Private _view As RssDesignerDataSourceView

		''' <summary>
		''' Gets a value indicating whether the <see cref="M:System.Web.UI.Design.DataSourceDesigner.Configure"></see> method can be called.
		''' </summary>
		''' <value></value>
		''' <returns>true, if <see cref="M:System.Web.UI.Design.DataSourceDesigner.Configure"></see> can be called; otherwise, false. The default is false.</returns>
		Public Overloads Overrides ReadOnly Property CanConfigure() As Boolean
			Get
				Return True
			End Get
		End Property

		''' <summary>
		''' Initializes the control designer and loads the specified component.
		''' </summary>
		''' <param name="component">The control being designed.</param>
		Public Overloads Overrides Sub Initialize(ByVal component As IComponent)
			MyBase.Initialize(component)
			_dataSource = DirectCast(component, RssDataSource)
		End Sub

		''' <summary>
		''' Launches the data source configuration utility in the design host.
		''' </summary>
		Public Overloads Overrides Sub Configure()
			InvokeTransactedChange(Component, New TransactedChangeCallback(ConfigureRssDataSource), Nothing, "Configure Data Source")
		End Sub

		''' <summary>
		''' Retrieves a <see cref="T:System.Web.UI.Design.DesignerDataSourceView"></see> object that is identified by the view name.
		''' </summary>
		''' <param name="viewName">The name of the view.</param>
		''' <returns>This implementation always returns null.</returns>
		Public Overloads Overrides Function GetView(ByVal viewName As String) As DesignerDataSourceView
			If _view Is Nothing Then
				_view = New RssDesignerDataSourceView(Me, viewName)
			End If

			Return _view
		End Function

		Private Function ConfigureRssDataSource(ByVal context As Object) As Boolean
			Try
				SuppressDataSourceEvents()

				Dim oldUrl As String = _dataSource.Url

				Using form As New RssDataSourceConfigForm(_dataSource)
					Dim uiService As IUIService = DirectCast(GetService(GetType(IUIService)), IUIService)
					Dim result As DialogResult = uiService.ShowDialog(form)

					If result = DialogResult.OK AndAlso oldUrl <> _dataSource.Url Then
						OnSchemaRefreshed(EventArgs.Empty)
					End If

					Return (result = DialogResult.OK)
				End Using
			Finally
				ResumeDataSourceEvents()
			End Try
		End Function

		Private Class RssDesignerDataSourceView
			Inherits DesignerDataSourceView
			Private _owner As RssDataSourceDesigner

			''' <summary>
			''' Initializes a new instance of the <see cref="RssDesignerDataSourceView"/> class.
			''' </summary>
			''' <param name="owner">The owner.</param>
			''' <param name="viewName">Name of the view.</param>
			Public Sub New(ByVal owner As RssDataSourceDesigner, ByVal viewName As String)
				MyBase.New(owner, viewName)
				_owner = owner
			End Sub

			''' <summary>
			''' Gets a schema that describes the data source view that is represented by this view object.
			''' </summary>
			''' <value></value>
			''' <returns>An <see cref="T:System.Web.UI.Design.IDataSourceViewSchema"></see>.</returns>
			Public Overloads Overrides ReadOnly Property Schema() As IDataSourceViewSchema
				Get
					Dim rss As RssDocument = _owner._dataSource.Rss

					If rss.Channel IsNot Nothing AndAlso rss.Channel.Items IsNot Nothing AndAlso rss.Channel.Items.Count = 0 Then
						Return MyBase.Schema
					End If

					'''/ create a DataTable and infer schema from there
					Dim dt As DataTable = rss.ToDataSet().Tables("item")
					Return New DataSetViewSchema(dt)
				End Get
			End Property
		End Class
	End Class
End Namespace
