'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Text
Imports System.Web
Imports System.Web.UI
Imports System.Web.UI.Design
Imports System.Web.UI.WebControls
Imports System.Windows.Forms
Imports System.Windows.Forms.Design
Imports DotNetNuke.Modules.News.RssToolkit.Web.WebControls

Namespace DotNetNuke.Modules.News.RssToolkit.Web.Design
	''' <summary>
	''' Rss Data Source View
	''' </summary>
	Public Class RssDataSourceView
		Inherits DataSourceView
		Private _owner As RssDataSource

		Friend Sub New(ByVal owner As RssDataSource, ByVal viewName As String)
			MyBase.New(owner, viewName)
			_owner = owner
		End Sub

		''' <summary>
		''' Gets a list of data asynchronously from the underlying data storage.
		''' </summary>
		''' <param name="arguments">A <see cref="T:System.Web.UI.DataSourceSelectArguments"></see> that is used to request operations on the data beyond basic data retrieval.</param>
		''' <param name="callback">A <see cref="T:System.Web.UI.DataSourceViewSelectCallback"></see> delegate that is used to notify a data-bound control when the asynchronous operation is complete.</param>
		''' <exception cref="T:System.ArgumentNullException">The <see cref="T:System.Web.UI.DataSourceViewSelectCallback"></see> supplied is null.</exception>
		Public Overloads Overrides Sub [Select](ByVal arguments As DataSourceSelectArguments, ByVal callback As DataSourceViewSelectCallback)
			If callback Is Nothing Then
				Throw New ArgumentNullException("callback")
			End If

			callback(ExecuteSelect(arguments))
		End Sub

		''' <summary>
		''' Gets a list of data from the underlying data storage.
		''' </summary>
		''' <param name="arguments">A <see cref="T:System.Web.UI.DataSourceSelectArguments"></see> that is used to request operations on the data beyond basic data retrieval.</param>
		''' <returns>
		''' An <see cref="T:System.Collections.IEnumerable"></see> list of data from the underlying data storage.
		''' </returns>
		Protected Overloads Overrides Function ExecuteSelect(ByVal arguments As DataSourceSelectArguments) As IEnumerable
			Return _owner.Rss.SelectItems(_owner.MaxItems)
		End Function
	End Class
End Namespace
