'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Text
Imports System.Web
Imports System.Web.UI
Imports System.Web.UI.Design
Imports System.Web.UI.WebControls
Imports System.Windows.Forms
Imports System.Windows.Forms.Design
Imports DotNetNuke.Modules.News.RssToolkit.Rss
Imports DotNetNuke.Modules.News.RssToolkit.Web.Design

Namespace DotNetNuke.Modules.News.RssToolkit.Web.WebControls
	''' <summary>
	''' RSS data source control implementation, including the designer
	''' </summary>
	<Designer(GetType(RssDataSourceDesigner))> _
	<DefaultProperty("Url")> _
	Public Class RssDataSource
		Inherits DataSourceControl
		Private _maxItems As Integer
		Private _url As String
		Private _itemsView As RssDataSourceView
		Private _rss As RssDocument

		''' <summary>
		''' Initializes a new instance of the <see cref="RssDataSource"/> class.
		''' </summary>
		Public Sub New()
		End Sub

		''' <summary>
		''' Gets or sets the max items.
		''' </summary>
		''' <value>The max items.</value>
		Public Property MaxItems() As Integer
			Get
				Return _maxItems
			End Get

			Set
				_maxItems = value
			End Set
		End Property

		''' <summary>
		''' Gets or sets the URL.
		''' </summary>
		''' <value>The URL.</value>
		<System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1056:UriPropertiesShouldNotBeStrings")> _
		Public Property Url() As String
			Get
				Return _url
			End Get

			Set
				_rss = Nothing
				_url = value
			End Set
		End Property

		''' <summary>
		''' Gets the RSS.
		''' </summary>
		''' <value>The RSS.</value>
		Public ReadOnly Property Rss() As RssDocument
			Get
				If _rss Is Nothing Then
					_rss = RssDocument.Load(New System.Uri(_url), Nothing)
				End If

				Return _rss
			End Get
		End Property

		''' <summary>
		''' Gets the named data source view associated with the data source control.
		''' </summary>
		''' <param name="viewName">The name of the <see cref="T:System.Web.UI.DataSourceView"></see> to retrieve. In data source controls that support only one view, such as <see cref="T:System.Web.UI.WebControls.SqlDataSource"></see>, this parameter is ignored.</param>
		''' <returns>
		''' Returns the named <see cref="T:System.Web.UI.DataSourceView"></see> associated with the <see cref="T:System.Web.UI.DataSourceControl"></see>.
		''' </returns>
		Protected Overloads Overrides Function GetView(ByVal viewName As String) As DataSourceView
			If _itemsView Is Nothing Then
				_itemsView = New RssDataSourceView(Me, viewName)
			End If

			Return _itemsView
		End Function
	End Class
End Namespace
