'=======================================================================
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
'  KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'  IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'  PARTICULAR PURPOSE.
'=======================================================================


Imports System
Imports System.Collections
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Text
Imports System.Web
Imports System.Web.UI
Imports System.Web.UI.WebControls
Imports DotNetNuke.Modules.News.RssToolkit.Rss

Namespace DotNetNuke.Modules.News.RssToolkit.Web.WebControls
	''' <summary>
	''' RssHyperLink control - works with RssHttpHandler 
	''' </summary>
	Public Class RssHyperLink
		Inherits HyperLink
		Private _channelName As String
		Private _includeUserName As Boolean
		Private _renderStandardImage As Boolean

		''' <summary>
		''' Initializes a new instance of the <see cref="RssHyperLink"/> class.
		''' </summary>
		Public Sub New()
   Text = DotNetNuke.Modules.News.RssToolkit.Rss.Resources.RssToolkit.RssText
		End Sub

		''' <summary>
		''' Gets or sets the name of the channel.
		''' </summary>
		''' <value>The name of the channel.</value>
		Public Property ChannelName() As String
			Get
				Return _channelName
			End Get
			Set
				_channelName = value
			End Set
		End Property

		''' <summary>
		''' when flag is set, the current user'd name is passed to RssHttpHandler
		''' </summary>
		''' <value><c>true</c> if [include user name]; otherwise, <c>false</c>.</value>
		Public Property IncludeUserName() As Boolean
			Get
				Return _includeUserName
			End Get
			Set
				_includeUserName = value
			End Set
		End Property

		''' <summary>
		''' Gets or sets a value indicating whether to render standard image].
		''' </summary>
		''' <value><c>true</c> if [render standard image]; otherwise, <c>false</c>.</value>
		Public Property RenderStandardImage() As Boolean
			Get
				Return _renderStandardImage
			End Get
			Set
				_renderStandardImage = value
			End Set
		End Property

		''' <summary>
		''' Raises the <see cref="E:System.Web.Control.PreRender"></see> event.
		''' </summary>
		''' <param name="e">An <see cref="T:System.EventArgs"></see> object that contains the event data.</param>
		Protected Overloads Overrides Sub OnPreRender(ByVal e As EventArgs)
			' modify the NavigateUrl to include optional user name and channel name
   Dim channel As String = CStr(IIf(_channelName IsNot Nothing, _channelName, String.Empty))
   Dim user As String = CStr(IIf(_includeUserName, Context.User.Identity.Name, String.Empty))
			NavigateUrl = RssHttpHandlerHelper.GenerateChannelLink(NavigateUrl, channel, user)

			' add <link> to <head> tag (if <head runat=server> is present)
			If Page.Header IsNot Nothing Then
    Dim title As String = CStr(IIf(String.IsNullOrEmpty(channel), Text, channel))

				Page.Header.Controls.Add(New LiteralControl(String.Format(System.Globalization.CultureInfo.InvariantCulture, "" & Chr(13) & "" & Chr(10) & "<link rel=""alternate"" type=""application/rss+xml"" title=""{0}"" href=""{1}"" />", title, NavigateUrl)))
			End If

   ' String imgPath = "WindowsApplication1.Durer_Melancolia.jpg";
   ' Assembly asm = Assembly.GetExecutingAssembly();
   ' System.IO.Stream s = asm.GetManifestResourceStream(imgPath);
   ' this.pictureBox1.Image = Image.FromStream(s);
			If _renderStandardImage Then
			End If

			MyBase.OnPreRender(e)
		End Sub
	End Class
End Namespace
