﻿'
' DotNetNuke® - http://www.dotnetnuke.com
' Copyright (c) 2002-2008
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Imports DotNetNuke.Services.Exceptions
Imports DotNetNuke.Services.Localization.Localization

Namespace DotNetNuke.Modules.News
 Partial Public Class Settings
  Inherits Entities.Modules.ModuleSettingsBase

#Region " Private Members "
  Private Const LocalTransformationPath As String = "\Newsfeeds\Transformations"
  Private Const GlobalTransformationPath As String = "~/DesktopModules/News/Transformations"
  Private _portalTransformationPath As String = ""
#End Region

#Region " Properties "
  Public ReadOnly Property PortalTransformationPath() As String
   Get
    If _portalTransformationPath = "" Then
     _portalTransformationPath = "~/" & PortalSettings.HomeDirectory & LocalTransformationPath.Replace("\", "/")
    End If
    Return _portalTransformationPath
   End Get
  End Property
#End Region

#Region " Controls "
  Protected WithEvents ctlRSSxsl As UI.UserControls.UrlControl
#End Region

#Region " Base Method Implementations "
  ''' <summary>
  ''' Load the module's settings into the controls.
  ''' </summary>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Overrides Sub LoadSettings()
   Try
    If Not Page.IsPostBack Then

     ' Load Xsl dropdown
     If Not IO.Directory.Exists(PortalSettings.HomeDirectoryMapPath & LocalTransformationPath) Then
      IO.Directory.CreateDirectory(PortalSettings.HomeDirectoryMapPath & LocalTransformationPath)
     End If
     For Each f As String In IO.Directory.GetFiles(Server.MapPath(GlobalTransformationPath), "*.xsl?")
      Dim fName As String = Mid(f, f.LastIndexOf("\") + 2)
      ddXsl.Items.Add(New ListItem(fName & " [System]", GlobalTransformationPath & "/" & fName))
     Next
     For Each f As String In IO.Directory.GetFiles(PortalSettings.HomeDirectoryMapPath & LocalTransformationPath, "*.xsl?")
      Dim fName As String = Mid(f, f.LastIndexOf("\") + 2)
      ddXsl.Items.Add(New ListItem(fName & " [Portal]", PortalTransformationPath & "/" & fName))
     Next
     ddXsl.Items.Add(New ListItem(GetString("Other.Option", Me.LocalResourceFile), ""))

     Dim Settings As New ModuleSettings(Me.ModuleId)
     Dim xslsrc As String = Settings.XslUrl

     Try
      If xslsrc.StartsWith(GlobalTransformationPath) Or xslsrc.StartsWith(PortalTransformationPath) Then
       ddXsl.Items.FindByValue(xslsrc).Selected = True
      ElseIf xslsrc = "" Then
       ddXsl.Items.FindByValue(GlobalTransformationPath & "/Default.xsl").Selected = True
      Else
       ddXsl.Items.FindByValue("").Selected = True
      End If
     Catch ex As Exception
     End Try

     If Not DotNetNuke.Framework.AJAX.IsInstalled Then
      Settings.UseAjax = False
      chkUseAjax.Enabled = False
     End If

     With Settings
      txtDefaultCacheTime.Text = .DefaultCacheTime.ToString
      txtItemsToShow.Text = .ItemsToShow.ToString
      chkShowItemDetails.Checked = .ShowItemDetails
      chkShowItemDate.Checked = .ShowItemDate
      chkUseAjax.Checked = .UseAjax
      txtRetryTimes.Text = .RetryTimes.ToString
      txtRetryTimeOut.Text = .RetryTimeOut.ToString
     End With
     If ddXsl.SelectedValue = "" Then
      ctlRSSxsl.Visible = True
      If xslsrc <> "" Then
       ctlRSSxsl.Url = xslsrc
      Else
       ctlRSSxsl.UrlType = "U"
      End If
     Else
      ctlRSSxsl.Visible = False
     End If
    End If
   Catch exc As Exception
    ProcessModuleLoadException(Me, exc)
   End Try
  End Sub

  ''' <summary>
  ''' Write settings back to the Module settings class.
  ''' </summary>
  ''' <remarks>
  ''' </remarks>
  ''' <history>
  ''' 	[pdonker]	03/01/2008  Created
  ''' </history>
  Public Overrides Sub UpdateSettings()
   Try

    Dim Settings As New ModuleSettings(Me.ModuleId)
    With Settings
     .DefaultCacheTime = Integer.Parse(txtDefaultCacheTime.Text)
     If ddXsl.SelectedValue = "" Then
      .XslUrl = ctlRSSxsl.Url
     Else
      .XslUrl = ddXsl.SelectedValue
     End If
     .ItemsToShow = Integer.Parse(txtItemsToShow.Text)
     .ShowItemDetails = chkShowItemDetails.Checked
     .ShowItemDate = chkShowItemDate.Checked
     .UseAjax = chkUseAjax.Checked
     .RetryTimes = Integer.Parse(txtRetryTimes.Text)
     .RetryTimeOut = Integer.Parse(txtRetryTimeOut.Text)
     .Save()
    End With

   Catch exc As Exception
    ProcessModuleLoadException(Me, exc)
   End Try
  End Sub
#End Region

#Region " Event Handlers "
  Private Sub ddXsl_SelectedIndexChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles ddXsl.SelectedIndexChanged
   ctlRSSxsl.Visible = (ddXsl.SelectedValue = "")
  End Sub
#End Region

 End Class
End Namespace
